# 5g-core-common-schemas

Common schemas used in 5G core network services.

## Usage

Install the package:
```bash
pip install 5g-core-common-schemas
```

Use the library in your project:
```python
from fiveg_core_common_schemas.NfInstanceId import NfInstanceId

my_instance = NfInstanceId("banana")
```
